[−][src]Struct interledger_btp::BtpOutgoingService
A container for BTP/WebSocket connections that implements OutgoingService for sending outgoing ILP Prepare packets over one of the connected BTP connections.
Methods
impl<O, A> BtpOutgoingService<O, A> where
O: OutgoingService<A> + Clone,
A: BtpAccount + 'static, [src]
O: OutgoingService<A> + Clone,
A: BtpAccount + 'static,
pub fn new(ilp_address: Address, next: O) -> Self[src]
pub fn close(&self)[src]
Close all of the open WebSocket connections
pub fn handle_incoming<I>(self, incoming_handler: I) -> BtpService<I, O, A> where
I: IncomingService<A> + Clone + Send + 'static, [src]
I: IncomingService<A> + Clone + Send + 'static,
Convert this BtpOutgoingService into a bidirectional BtpService by adding a handler for incoming requests. This will automatically pull all incoming Prepare packets from the channel buffer and call the IncomingService with them.